#ifndef NT2_INCLUDE_CONSTANTS_DEGINRAD_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_DEGINRAD_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/deginrad.hpp>

#endif
